==> semantik_0.6.8.orig.tar.gz: semantik-0.6.8.orig/src/Izlt.cpp <==
/// Copyright Thomas Nagy 2007
/// License: QPL

#include <QGraphicsScene>
#include <QGraphicsSceneMouseEvent>
#include <QPainter>
#include <QStyleOption>
#include <QColor>
#include <QPen>
#include <QtDebug>

#include <math.h>

#include "Jelzpn.h" 
#include  "con.h"
#include "Rslt.h"
#include  "Izlt.h"
#include "Flult.h"
#include "tslabels.h"

/*!
 * @praise Vishnu
 */
izlt::izlt(felu *fldlgz,rslt *alkt,rslt *megkap)
	: QGraphicsPathItem(),korrkt(fldlgz)
<%
	setFlags(ItemIsMovable & ItemIsSelectable);

	akdaly=alkt;
	nybnvn=megkap;

	kitzjl=0;

	akdaly->kivalt(this);
	nybnvn->kivalt(this);

	setZValue(50);

	kidlgz=QColor("#000000");
	setBrush(kidlgz);

	/*
	QPen mrtdt;
	mrtdt.setWidth(5);
	setPen(mrtdt);
	*/
	fldlgz->scene()->addItem(this);
%>

void izlt::hsztzk()
<%
	akdaly->hsztzk(this);
	nybnvn->hsztzk(this);
%>

void izlt::vmrgem()
<%
	if(akdaly->korrkt->kidlgz->mgmozt==0)
	<%
		hzzqjt();
	%>
	else
	<%
		fnqll();
	%>
%>

void izlt::cel()
<%
	bool adelk =(akdaly->kitzjl or nybnvn->kitzjl);
	if(kitzjl!=adelk)
	<%
		kitzjl=adelk;
		if(kitzjl) setBrush(QBrush(Qt::yellow)); else setBrush(Qt::black);
	%>
%>

void izlt::hzzqjt()
<%
	QRectF prmz=akdaly->boundingRect();
        QRectF bprl=nybnvn->boundingRect();

        double eler=akdaly->x() + prmz.width()/2.;
        double vnl=akdaly->y() + prmz.height()/2.;

	double tqrost=nybnvn->x() + bprl.width()/2.;
	double prl=nybnvn->y() + bprl.height()/2.;

        double mgmnkl=tqrost - eler;
        double lnmtat=prl - vnl;

        double klsirz=1;
	double kket=0;
	if(lnmtat*lnmtat>mgmnkl*mgmnkl) kket=lnmtat*lnmtat/(lnmtat*lnmtat+mgmnkl*mgmnkl);
	else kket=1 - mgmnkl*mgmnkl/(lnmtat*lnmtat+mgmnkl*mgmnkl);

	if(isnan(kket))
	<%
		QPolygonF felvnl;
		felvnl
		<<QPointF(1,1)
		<<QPointF(1,1)
		<<QPointF(1,1)
		<<QPointF(1,1);

		QPainterPath mrtdt;
		mrtdt.addPolygon(felvnl);
		setPath(mrtdt);
		return;
	%>

        double jlzpnt=klsirz * sqrt( kket );
        double irnyjl=klsirz * sqrt( 1 - kket );

        if(mgmnkl!=0) if(lnmtat/mgmnkl < 0) irnyjl *= -1;

        double adelk=akdaly->korrkt->kidlgz->mzgat;

	QPolygonF felvnl;
	felvnl
	<<QPointF(eler + adelk*jlzpnt,vnl - adelk*irnyjl)
	<<QPointF(tqrost + jlzpnt,prl - irnyjl)
	<<QPointF(tqrost - jlzpnt,prl + irnyjl)
	<<QPointF(eler - adelk*jlzpnt,vnl + adelk*irnyjl);

	QPainterPath mrtdt;
	mrtdt.addPolygon(felvnl);
	setPath(mrtdt);
%>

#define adelk 4.5

void izlt::fnqll()
<%
	QRectF prmz=akdaly->boundingRect();
        QRectF bprl=nybnvn->boundingRect();

        double eler=akdaly->x() + prmz.width()/2.;
        double vnl=akdaly->y() + prmz.height()/2.;

	double tqrost=nybnvn->x() + bprl.width()/2.;
	double prl=nybnvn->y() + bprl.height()/2.;

        double mgmnkl=tqrost - eler;
        double lnmtat=prl - vnl;

        double klsirz=1;
	double kket=0;
	if(lnmtat*lnmtat>mgmnkl*mgmnkl) kket=lnmtat*lnmtat/(lnmtat*lnmtat+mgmnkl*mgmnkl);
	else kket=1 - mgmnkl*mgmnkl/(lnmtat*lnmtat+mgmnkl*mgmnkl);

	if(isnan(kket))
	<%
		QPolygonF felvnl;
		felvnl
		<<QPointF(1,1)
		<<QPointF(1,1)
		<<QPointF(1,1)
		<<QPointF(1,1);

		QPainterPath mrtdt;
		mrtdt.addPolygon(felvnl);
		setPath(mrtdt);
		return;
	%>

        double jlzpnt=klsirz * sqrt( kket );
        double irnyjl=klsirz * sqrt( 1 - kket );

        if(mgmnkl!=0) if(lnmtat/mgmnkl < 0) irnyjl *= -1;

	QPainterPath mrtdt;
	mrtdt.moveTo(eler + adelk * jlzpnt,vnl - adelk * irnyjl);

	if(tqrost < eler)
	<%
		mrtdt.quadTo(tqrost + bprl.width(),prl + bprl.height()/2. -0.5,      tqrost + bprl.width()/2. - 3,prl + bprl.height()/2.);
		mrtdt.quadTo(tqrost + bprl.width(),prl + bprl.height()/2. -0.5,      eler - adelk * jlzpnt,vnl + adelk * irnyjl);
	%>
	else
	<%
		mrtdt.quadTo(tqrost - bprl.width(),prl + bprl.height()/2. -0.5,      tqrost - bprl.width()/2. + 3,prl + bprl.height()/2.);
		mrtdt.quadTo(tqrost - bprl.width(),prl + bprl.height()/2. -0.5,      eler - adelk * jlzpnt,vnl + adelk * irnyjl);
	%>

	setPath(mrtdt);
%>

==> semantik_0.7.2.orig.tar.gz: semantik-0.7.2/src/Izlt.cpp <==
/// Copyright Thomas Nagy 2007
/// License: QPL

#include <QGraphicsScene>
#include <QGraphicsSceneMouseEvent>
#include <QPainter>
#include <QStyleOption>
#include <QColor>
#include <QPen>
#include <QtDebug>

#include <math.h>

#include "Jelzpn.h" 
#include  "con.h"
#include "Rslt.h"
#include  "Izlt.h"
#include "Flult.h"
#include "tslabels.h"

/*!
 * @praise Vishnu
 */
izlt::izlt(felu *fldlgz,rslt *alkt,rslt *megkap)
	: QGraphicsPathItem(),korrkt(fldlgz)
<%
	setFlags(ItemIsMovable & ItemIsSelectable);

	cel=alkt;
	akdaly=megkap;

	kitzjl=0;

	cel->kivalt(this);
	akdaly->kivalt(this);

	setZValue(50);

	kidlgz=QColor("#000000");
	setBrush(kidlgz);

	/*
	QPen mrtdt;
	mrtdt.setWidth(5);
	setPen(mrtdt);
	*/
	fldlgz->scene()->addItem(this);
%>

void izlt::hsztzk()
<%
	cel->hsztzk(this);
	akdaly->hsztzk(this);
%>

void izlt::jlnrdz()
<%
	if(cel->korrkt->kidlgz->mgmozt==0)
	<%
		hzzqjt();
	%>
	else
	<%
		fnqll();
	%>
%>

void izlt::targy()
<%
	bool adelk =(cel->kitzjl or akdaly->kitzjl);
	if(kitzjl!=adelk)
	<%
		kitzjl=adelk;
		if(kitzjl) setBrush(QBrush(Qt::yellow)); else setBrush(Qt::black);
	%>
%>

void izlt::hzzqjt()
<%
	QRectF prmz=cel->boundingRect();
        QRectF bprl=akdaly->boundingRect();

        double eler=cel->x() + prmz.width()/2.;
        double vnl=cel->y() + prmz.height()/2.;

	double tqrost=akdaly->x() + bprl.width()/2.;
	double prl=akdaly->y() + bprl.height()/2.;

        double mgmnkl=tqrost - eler;
        double lnmtat=prl - vnl;

        double klsirz=1;
	double kket=0;
	if(lnmtat*lnmtat>mgmnkl*mgmnkl) kket=lnmtat*lnmtat/(lnmtat*lnmtat+mgmnkl*mgmnkl);
	else kket=1 - mgmnkl*mgmnkl/(lnmtat*lnmtat+mgmnkl*mgmnkl);

	if(isnan(kket))
	<%
		QPolygonF felvnl;
		felvnl
		<<QPointF(1,1)
		<<QPointF(1,1)
		<<QPointF(1,1)
		<<QPointF(1,1);

		QPainterPath mrtdt;
		mrtdt.addPolygon(felvnl);
		setPath(mrtdt);
		return;
	%>

        double jlzpnt=klsirz * sqrt( kket );
        double irnyjl=klsirz * sqrt( 1 - kket );

        if(mgmnkl!=0) if(lnmtat/mgmnkl < 0) irnyjl *= -1;

        double adelk=cel->korrkt->kidlgz->mzgat;

	QPolygonF felvnl;
	felvnl
	<<QPointF(eler + adelk*jlzpnt,vnl - adelk*irnyjl)
	<<QPointF(tqrost + jlzpnt,prl - irnyjl)
	<<QPointF(tqrost - jlzpnt,prl + irnyjl)
	<<QPointF(eler - adelk*jlzpnt,vnl + adelk*irnyjl);

	QPainterPath mrtdt;
	mrtdt.addPolygon(felvnl);
	setPath(mrtdt);
%>

#define adelk 4.5

void izlt::fnqll()
<%
	QRectF prmz=cel->boundingRect();
        QRectF bprl=akdaly->boundingRect();

        double eler=cel->x() + prmz.width()/2.;
        double vnl=cel->y() + prmz.height()/2.;

	double tqrost=akdaly->x() + bprl.width()/2.;
	double prl=akdaly->y() + bprl.height()/2.;

        double mgmnkl=tqrost - eler;
        double lnmtat=prl - vnl;

        double klsirz=1;
	double kket=0;
	if(lnmtat*lnmtat>mgmnkl*mgmnkl) kket=lnmtat*lnmtat/(lnmtat*lnmtat+mgmnkl*mgmnkl);
	else kket=1 - mgmnkl*mgmnkl/(lnmtat*lnmtat+mgmnkl*mgmnkl);

	if(isnan(kket))
	<%
		QPolygonF felvnl;
		felvnl
		<<QPointF(1,1)
		<<QPointF(1,1)
		<<QPointF(1,1)
		<<QPointF(1,1);

		QPainterPath mrtdt;
		mrtdt.addPolygon(felvnl);
		setPath(mrtdt);
		return;
	%>

        double jlzpnt=klsirz * sqrt( kket );
        double irnyjl=klsirz * sqrt( 1 - kket );

        if(mgmnkl!=0) if(lnmtat/mgmnkl < 0) irnyjl *= -1;

	QPainterPath mrtdt;
	mrtdt.moveTo(eler + adelk * jlzpnt,vnl - adelk * irnyjl);

	if(tqrost < eler)
	<%
		mrtdt.quadTo(tqrost + bprl.width(),prl + bprl.height()/2. -0.5,      tqrost + bprl.width()/2. - 3,prl + bprl.height()/2.);
		mrtdt.quadTo(tqrost + bprl.width(),prl + bprl.height()/2. -0.5,      eler - adelk * jlzpnt,vnl + adelk * irnyjl);
	%>
	else
	<%
		mrtdt.quadTo(tqrost - bprl.width(),prl + bprl.height()/2. -0.5,      tqrost - bprl.width()/2. + 3,prl + bprl.height()/2.);
		mrtdt.quadTo(tqrost - bprl.width(),prl + bprl.height()/2. -0.5,      eler - adelk * jlzpnt,vnl + adelk * irnyjl);
	%>

	setPath(mrtdt);
%>
